export interface AudioPeakOptions {
    numberOfBuckets?: number;
    channel?: number;
}
/**
 * Generates an array of peak values from an AudioBuffer
 * @param buffer - The AudioBuffer to analyze
 * @param options - Configuration options for peak generation
 * @returns Array of normalized peak values
 */
export declare function getPeaks(buffer: AudioBuffer, options?: AudioPeakOptions): number[];
/**
 * Creates an AudioBuffer from an audio file
 * @param file - Audio file to process
 * @returns Promise resolving to AudioBuffer
 */
export declare function createAudioBuffer(file: File): Promise<AudioBuffer>;
/**
 * Utility function to normalize peak values
 * @param peaks - Array of peak values
 * @returns Normalized peak values between 0 and 1
 */
export declare function normalizePeaks(peaks: number[]): number[];
/**
 * Type guard to check if a value is an AudioBuffer
 */
export declare function isAudioBuffer(value: any): value is AudioBuffer;
/**
 * Formats time in seconds to a string in HH:MM:SS or MM:SS format.
 * @param seconds - The time in seconds to format.
 * @returns A formatted time string (e.g., "02:34", "01:02:34").
 */
export declare function formatTime(seconds: number): string;
